==> opennms-config-model-21.0.0-20170623.161227-17-sources.jar: org/opennms/netmgt/config/threshd/ThresholdType.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config.threshd;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name="type")
@XmlEnum
public enum ThresholdType {
    @XmlEnumValue("high")
    HIGH("high"),
    @XmlEnumValue("low")
    LOW("low"),
    @XmlEnumValue("relativeChange")
    RELATIVE_CHANGE("relativeChange"),
    @XmlEnumValue("absoluteChange")
    ABSOLUTE_CHANGE("absoluteChange"),
    @XmlEnumValue("rearmingAbsoluteChange")
    REARMING_ABSOLUTE_CHANGE("rearmingAbsoluteChange");
    
    private String m_enumName;

    ThresholdType(final String enumName) {
        m_enumName = enumName;
    }
    
    public String getEnumName() {
        return m_enumName;
    }
}

==> opennms-config-model-21.1.0-20190109.184343-34-sources.jar: org/opennms/netmgt/config/threshd/ThresholdType.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.config.threshd;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlRootElement;

@XmlRootElement(name="type")
@XmlEnum
public enum ThresholdType {
    @XmlEnumValue("high")
    HIGH("high"),
    @XmlEnumValue("low")
    LOW("low"),
    @XmlEnumValue("relativeChange")
    RELATIVE_CHANGE("relativeChange"),
    @XmlEnumValue("absoluteChange")
    ABSOLUTE_CHANGE("absoluteChange"),
    @XmlEnumValue("rearmingAbsoluteChange")
    REARMING_ABSOLUTE_CHANGE("rearmingAbsoluteChange");
    
    private String m_enumName;

    ThresholdType(final String enumName) {
        m_enumName = enumName;
    }
    
    public String getEnumName() {
        return m_enumName;
    }

    public static ThresholdType forName(final String name) {
        for (final ThresholdType type : ThresholdType.values()) {
            if (name.equalsIgnoreCase(type.getEnumName())) {
                return type;
            }
        }
        return null;
    }
}
